@@ -8,12 +8,12 @@ class Experimental(FileX):
     Class to create Experimental files
     """
 
-    def write_file(self):
+    def write_file(self, folder = "C:/DSSAT47/Cassava"):
         """
         Method to write the Experimental file. Must be executed after all the preparation.
         """
 
-        with open(f"C:/DSSAT47/Cassava/{self._filename}.CSX", mode="w") as file:
+        with open(f"{folder}/{self._filename}.CSX", mode="w") as file:
 
             # Head
             w_file.write_head(file, self._filename, self._exp_name)
@@ -28,7 +28,7 @@ class Experimental(FileX):
             w_file.write_field(file, self._field)
 
             # Initial Conditions
-            w_file.write_initial_conditions(file, self._sim_start)
+            w_file.write_initial_conditions(file, self._date_start, self.soil_params)
 
             # Planting
             w_file.write_planting(file, self._planting_julian)
@@ -43,9 +43,9 @@ class Experimental(FileX):
             w_file.write_harvest(file, self._harvest)
 
             # Controls
-            w_file.write_controls(file, self._sim_start)
+            w_file.write_controls(file, self._sim_start, self._date_start, self.years)
 
-        print(f'\n "{self._filename}.CSX" file available at C:/DSSAT47/Cassava')
+        print(f'\n "{self._filename}.CSX" file available at {folder}')
 
 
 class Seasonal(FileX):
@@ -73,7 +73,7 @@ class Seasonal(FileX):
             w_file.write_field(file, self._field)
 
             # Initial Conditions
-            w_file.write_initial_conditions(file, self._sim_start)
+            w_file.write_initial_conditions(file, self._date_start, self.soil_params)
 
             # Planting
             w_file.write_planting(file, self._planting_julian)
@@ -88,6 +88,6 @@ class Seasonal(FileX):
             w_file.write_harvest(file, self._harvest)
 
             # Controls
-            w_file.write_controls(file, self._sim_start, years=31, mode="seas")
+            w_file.write_controls(file, self._sim_start, self._date_start, self.years)
 
         print(f'\n "{self._filename}.SNX" file available at C:/DSSAT47/Seasonal')
