@@ -1,9 +1,12 @@
 from datetime import date
 from datetime import timedelta as td
 import numpy as np
+from itertools import chain
 
+from .soil import Soil
 from . import exp_functions as exp
 
+
 class FileX:
     """
     Parent class for all Files (Experimental and Seasonal)
@@ -98,25 +101,37 @@ class FileX:
 
         self._harvest = [date.strftime("%y%j") for date in dates]
 
-    def set_simulation_start(self, sim_start):
+    def set_controls(self, sim_start, date_start = None, years=1):
         """
-        Method to define simulation start date.
+        Method to define simulation start date and soil water available at the simulation beginning.
 
         Parameters
         ----------
             sim_start: str
-                Must be a 'dd-mm-yyyy' date ('01-05-2020').
+                Must be "P" (simulation start on planting) or "S" (simulation start on a specified date). If "S", the "date_start" argument is necessary.
+
+            date_start: str
+                Obligatory if "sim_start" is "S". Must be a 'dd-mm-yyyy' date ('01-05-2020').
+            
+
         """
+        self._sim_start = sim_start
 
-        sim_start = date.fromisoformat(sim_start)
-        self._sim_start = sim_start.strftime("%y%j")
+        if date_start is not None:
+            date_start = date.fromisoformat(date_start)
+            self._date_start = date_start.strftime("%y%j")
 
-    def set_field(self, code_id, soil_id):
+        self.years = years
+
+    def set_field(self, code_id, soil_id, water=1):
         """
         Method to define simulation field.
 
         Parameters
         ----------
+            water: int
+                Value between 0 and 1 (0% - 100%) meaning percentage of soil water
+
             code_id: str
                 DSSAT ID for the weather station (found on .WTH files)
 
@@ -124,29 +139,35 @@ class FileX:
                 DSSAT ID for the soil (found on .SOIL files)
         """
 
+        if water < 0 or water > 1:
+            raise ValueError(f"value {water} for 'water' parameter invalid")
+
         self._field = code_id, soil_id
+        self.soil_params = Soil(soil_id).params
+
+        self._water_available(water)
 
     def set_genotype(self, genotype):
         """
-        Method to define the genotype.
+        Method to define genotypes. For each genotype inserted the tratment number is doubled.
 
         Parameters
         ----------
-            genotype: list of two str
-                genotype DSSAT code (found on .CUL files)
-                The first element is the ecotype code
-                The second element is the genotype code
+            genotype: list of tuples
+                each tuple must have two string elements
+                The first element is the ecotype code (ex: 'UC0007')
+                The second element is the genotype code ('MCol-1684')
         """
 
-        self._genotype = genotype
+        self._genotype = exp.validate_genotype_input(genotype)
 
     def set_irrigation(self, laminas, n_irrig="NULL", from_irrig="NULL", by_irrig="NULL",
                        reg="NULL", trat_irrig="NULL"):
         """
         Method to define irrigation.
-        If "irf" design is setting, parameters 'laminas', 'n_irrig', 'from_irrig' and 'by_irrig'
+        If "irf" design is set, parameters 'laminas', 'n_irrig', 'from_irrig' and 'by_irrig'
         are mandatory and a DAP (days after planting) sequence logic is used. If "irnf" design is
-        setting, parameters 'laminas', 'reg' and 'trat_irrig' are mandatory and DAP must be setted
+        set, parameters 'laminas', 'reg' and 'trat_irrig' are mandatory and DAP must be setted
         manually.
 
         Parameters
@@ -206,30 +227,41 @@ class FileX:
 
     def set_tratmatrix(self, tnames_prefix):
         """
-        After run all necessary 'set_*' functions, this method closes the File preparation setting
+        After run all necessary 'set_*' functions, this method closes the File preparation and set
         the treatment matrix.
 
         Parameters
         ----------
 
             tnames_prefix: str
-                An user code for all treatments inside this file. Can be usefull if you run more
+                A code for all treatments inside this file. Can be usefull if you run more
                 than one file per time.
         """
-
         if "phf" in self._design:
-
             self._tratmatrix = exp.fix_PlantHarv(self._planting, self._harvest)
-
         else:
             self._tratmatrix = exp.not_fix_PlantHarv(self._planting, self._harvest)
 
         if "irf" in self._design or "irnf" in self._design:
-
             self._tratmatrix = exp.trat_insert_irrig(self._trat_irrig, self._tratmatrix)
-
         else:
             self._tratmatrix = exp.insert_all_rainfed(self._tratmatrix)
 
-        self._tratmatrix = exp.set_tratnames(self._tratmatrix, tnames_prefix)
+        # To insert more than one genotype by file
+        genotype_list = [[i] * len(self._tratmatrix) for i in range(1, len(self._genotype) + 1)]
+        genotype_list = list(chain.from_iterable(genotype_list))
 
+        self._tratmatrix = self._tratmatrix * len(self._genotype)  # reference trap!
+
+        new_tratmatrix = []
+        for i, gen_id in enumerate(genotype_list):
+            trat = self._tratmatrix[i][:]      # '[:]' get the value instead of reference
+            trat.insert(0, gen_id)
+            new_tratmatrix.append(trat)
+
+        self._tratmatrix = exp.set_tratnames(new_tratmatrix, tnames_prefix)
+
+    def _water_available(self, water):
+
+        self.soil_params["SH2O"] = [round(w * water + self.soil_params["SLLL"][i], 3)
+                                    for i, w in enumerate(self.soil_params["SH2O"])]
